@@ -31,7 +31,7 @@ count_event_by <- function(formula, data, count_by_var = NULL, var_subgroup = NU
   total_count <- nrow(data)
   total_event_count <- sum(data[[event_col]] == 1, na.rm = TRUE)
   total_event_rate <- paste0(total_event_count, "/", total_count, " (", round(total_event_count / total_count * 100, decimal.percent), "%)")
-
+  
   if (!is.null(count_by_var) && !is.null(var_subgroup)) {
     # count_by_var와 var_subgroup이 모두 있을 때
     counts <- data %>%
@@ -39,7 +39,7 @@ count_event_by <- function(formula, data, count_by_var = NULL, var_subgroup = NU
       dplyr::group_by(!!rlang::sym(count_by_var), !!rlang::sym(var_subgroup)) %>%
       dplyr::summarize(Count = dplyr::n(), Event_Count = sum(!!rlang::sym(event_col) == 1, na.rm = TRUE), .groups = "drop") %>%
       dplyr::mutate(Event_Rate = paste0(Event_Count, "/", Count, " (", round(Event_Count / Count * 100, decimal.percent), "%)"))
-
+    
     overall_counts <- data %>%
       dplyr::group_by(!!rlang::sym(count_by_var)) %>%
       dplyr::summarize(Count = dplyr::n(), Event_Count = sum(!!rlang::sym(event_col) == 1, na.rm = TRUE), .groups = "drop") %>%
@@ -47,7 +47,7 @@ count_event_by <- function(formula, data, count_by_var = NULL, var_subgroup = NU
         Event_Rate = paste0(Event_Count, "/", Count, " (", round(Event_Count / Count * 100, decimal.percent), "%)"),
         !!rlang::sym(var_subgroup) := "Overall"
       )
-
+    
     counts <- counts %>%
       dplyr::bind_rows(overall_counts) %>%
       dplyr::arrange(!!rlang::sym(count_by_var), !!rlang::sym(var_subgroup))
@@ -74,16 +74,16 @@ count_event_by <- function(formula, data, count_by_var = NULL, var_subgroup = NU
     )
     return(counts)
   }
-
+  
   # Total 행을 추가
   total_row <- tibble::tibble(
     Count = total_count,
     Event_Count = total_event_count,
     Event_Rate = total_event_rate
   )
-
+  
   counts <- dplyr::bind_rows(counts, total_row)
-
+  
   return(counts)
 }
 
@@ -145,10 +145,12 @@ count_event_by <- function(formula, data, count_by_var = NULL, var_subgroup = NU
 #' @importFrom survey svycoxph regTermTest
 #' @importFrom stats confint coefficients
 #' @importFrom utils tail
-
+#' @importFrom coxme coxme
+#' @importFrom car Anova
 
 TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data, time_eventrate = 3 * 365, decimal.hr = 2, decimal.percent = 1, decimal.pvalue = 3, cluster = NULL, strata = NULL, weights = NULL, event = FALSE, count_by = NULL, labeldata = NULL) {
   . <- variable <- val_label <- NULL
+  is_mixed_effect <- grepl("\\|", deparse(formula))
   if (is.null(count_by) && !(event)) {
     ### var_subgroup이 categorical variable이 아닌 경우 중단 ###
     if (any(class(data) == "survey.design" & !is.null(var_subgroup))) {
@@ -158,7 +160,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
       if (is.numeric(data[[var_subgroup]])) stop("var_subgroup must categorical.")
       # if (length(levels(data[[as.character(formula[[3]])]])) != 2) stop("Independent variable must have 2 levels.")
     }
-
+    
     ## functions with error
     possible_table <- purrr::possibly(table, NA)
     possible_prop.table <- purrr::possibly(function(x) {
@@ -176,32 +178,32 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
     possible_rowone <- purrr::possibly(function(x) {
       x[1, ]
     }, NA)
-
+    
     formula.km <- formula
     var_cov <- setdiff(var_cov, c(as.character(formula[[3]]), var_subgroup))
     xlabel <- setdiff(as.character(formula)[[3]], "+")[1]
-
+    
     ncoef <- ifelse(any(class(data) == "survey.design"), ifelse(length(levels(data$variables[[xlabel]])) <= 2, 1, length(levels(data$variables[[xlabel]])) - 1),
-      ifelse(length(levels(data[[xlabel]])) <= 2 || is.numeric(data[[xlabel]]), 1, length(levels(data[[xlabel]])) - 1)
+                    ifelse(length(levels(data[[xlabel]])) <= 2 || is.numeric(data[[xlabel]]), 1, length(levels(data[[xlabel]])) - 1)
     )
-
+    
     if (is.null(var_subgroup)) {
       ### subgroup 지정 안 한 경우 ###
       # 공변량 있는 경우 formula 변경
       if (!is.null(var_cov)) {
         formula <- as.formula(paste0(deparse(formula), " + ", paste(var_cov, collapse = "+")))
       }
-
+      if(!is_mixed_effect){
       # Strata !is.null인 경우 formula 변경
       if (!is.null(strata)) {
         formula <- as.formula(paste0(deparse(formula), " + ", paste0("strata(", strata, ")")))
       }
-
+      
       if (any(class(data) == "survey.design")) {
         ### survey data인 경우 ###
         model <- survey::svycoxph(formula, design = data, x = T)
         # if (!is.null(model$xlevels) & length(model$xlevels[[1]]) != 2) stop("Categorical independent variable must have 2 levels.")
-
+        
         # KM 구하기(categorical인 경우)
         if (is.numeric(data$variables[[xlabel]])) {
           prop <- NULL
@@ -236,7 +238,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           model <- eval(cc)
         }
         # if (!is.null(model$xlevels) & length(model$xlevels[[1]]) != 2) stop("Categorical independent variable must have 2 levels.")
-
+        
         # KM 구하기(categorical인 경우)
         if (is.numeric(data[[xlabel]])) {
           prop <- NULL
@@ -248,24 +250,48 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
         }
         # out.kap <- paste(res.kap.times[["n.event"]], " (", round(100 * (1 - res.kap.times[["surv"]]), decimal.percent), ")", sep = "")
       }
-
+      
       # PE, CI, PV 구하기
       Point.Estimate <- round(exp(coef(model)), decimal.hr)[1:ncoef]
-
+      
       # if (length(Point.Estimate) > 1){
       #  stop("Formula must contain 1 independent variable only.")
       # }
-
+      
       CI <- round(exp(confint(model)[1:ncoef, ]), decimal.hr)
       event <- purrr::map_dbl(model$y, 1) %>% tail(model$n)
       # prop <- round(prop.table(table(event, model$x[, 1]), 2)[2, ] * 100, decimal.percent)
       pv <- round(summary(model)$coefficients[1:ncoef, "Pr(>|z|)"], decimal.pvalue)
-
+      }
+      else{
+        prop<-NULL
+        model <- coxme::coxme(formula, data = data)
+        model_sum <- summary(model)
+        Point.Estimate <- round(exp(model_sum$coef[, "coef"]), decimal.hr)
+        Lower <- round(exp(model_sum$coef[, "coef"] - 1.96 * model_sum$coef[, "se(coef)"]), decimal.hr)
+        Upper <- round(exp(model_sum$coef[, "coef"] + 1.96 * model_sum$coef[, "se(coef)"]), decimal.hr)
+        CI <- cbind(Lower, Upper)
+        dimnames(CI) <- list(names(Point.Estimate), c("2.5 %", "97.5 %"))
+        pv <- round(model_sum$coef[, "p"], decimal.pvalue)
+        result_levels <- names(Point.Estimate)
+        rhs <- as.character(formula)[3]         
+        fixed_effect <- gsub("\\+\\s*\\(.*\\)", "", rhs)  
+        xlabel <- trimws(fixed_effect)
+        xlev <- levels(data[[xlabel]])
+        if(is.factor(data[[xlabel]])) {
+          ncoef <- length(xlev) - 1
+        } else {
+          ncoef <- length(xlev)
+        }
+      }
+      
       # output 만들기
+      count_val <- if (is_mixed_effect) model$n[2] else model$n
+      xlev <-if (is_mixed_effect) xlev else model$xlevels[[1]]
       if (ncoef < 2) {
-        out <- data.frame(Variable = "Overall", Count = model$n, Percent = 100, `Point Estimate` = Point.Estimate, Lower = CI[1], Upper = CI[2], check.names = F) %>%
+        out <- data.frame(Variable = "Overall", Count = count_val, Percent = 100, `Point Estimate` = Point.Estimate, Lower = CI[1], Upper = CI[2], check.names = F) %>%
           mutate(`P value` = ifelse(pv >= 0.001, pv, "<0.001"), `P for interaction` = NA)
-
+        
         if (!is.null(names(prop))) {
           out <- data.frame(Variable = "Overall", Count = model$n, Percent = 100, `Point Estimate` = Point.Estimate, Lower = CI[1], Upper = CI[2], check.names = F) %>%
             cbind(t(prop)) %>%
@@ -273,28 +299,28 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
         }
       } else {
         out <- data.frame(
-          Variable = c("Overall", rep("", length(Point.Estimate))), Count = c(model$n, rep("", length(Point.Estimate))), Percent = c(100, rep("", length(Point.Estimate))),
-          Levels = paste0(xlabel, "=", model$xlevels[[1]]), `Point Estimate` = c("Reference", Point.Estimate), Lower = c("", CI[, 1]), Upper = c("", CI[, 2]), check.names = F
+          Variable = c("Overall", rep("", length(Point.Estimate))), Count = c(count_val, rep("", length(Point.Estimate))), Percent = c(100, rep("", length(Point.Estimate))),
+          Levels = paste0(xlabel, "=", xlev), `Point Estimate` = c("Reference", Point.Estimate), Lower = c("", CI[, 1]), Upper = c("", CI[, 2]), check.names = F
         ) %>%
           mutate(`P value` = c("", ifelse(pv >= 0.001, pv, "<0.001")), `P for interaction` = NA)
-
+        
         if (!is.null(names(prop))) {
           out <- data.frame(
-            Variable = c("Overall", rep("", length(Point.Estimate))), Count = c(model$n, rep("", length(Point.Estimate))), Percent = c(100, rep("", length(Point.Estimate))),
+            Variable = c("Overall", rep("", length(Point.Estimate))), Count = c(count_val, rep("", length(Point.Estimate))), Percent = c(100, rep("", length(Point.Estimate))),
             Levels = paste0(xlabel, "=", model$xlevels[[1]]), `Point Estimate` = c("Reference", Point.Estimate), Lower = c("", CI[, 1]), Upper = c("", CI[, 2]), KM = prop, check.names = F
           ) %>%
             mutate(`P value` = c("", ifelse(pv >= 0.001, pv, "<0.001")), `P for interaction` = NA)
         }
-
+        
         rownames(out) <- NULL
-
+        
         if (!is.null(labeldata)) {
-          out$Levels <- paste0(labeldata[variable == xlabel, var_label[1]], "=", sapply(model$xlevels[[1]], function(x) {
+          out$Levels <- paste0(labeldata[variable == xlabel, var_label[1]], "=", sapply(xlev, function(x) {
             labeldata[variable == xlabel & labeldata$level == x, val_label]
           }))
         }
       }
-
+      
       return(out)
     } else if (length(var_subgroup) > 1 | any(grepl(var_subgroup, formula))) {
       stop("Please input correct subgroup variable.")
@@ -304,12 +330,12 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
       if (!is.null(var_cov)) {
         formula <- as.formula(paste0(deparse(formula), " + ", paste(var_cov, collapse = "+")))
       }
-
+      if (!is_mixed_effect){
       # Strata !is.null인 경우 formula 변경
       if (!is.null(strata)) {
         formula <- as.formula(paste0(deparse(formula), " + ", paste0("strata(", strata, ")")))
       }
-
+      
       if (any(class(data) == "survey.design")) {
         ### survey data인 경우 ###
         data$variables[[var_subgroup]] <- factor(data$variables[[var_subgroup]])
@@ -318,7 +344,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           names() -> label_val
         label_val %>% purrr::map(~ possible_svycoxph(formula, design = subset(data, get(var_subgroup) == .), x = TRUE)) -> model
         xlev <- survey::svycoxph(formula, design = data)$xlevels
-
+        
         # pv_int 구하기
         pv_int <- tryCatch(
           {
@@ -332,17 +358,17 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
             return(NA)
           }
         )
-
+        
         ## interaction 여러개인 경우 pv_int 구하기
         model.int <- possible_svycoxph(as.formula(gsub(xlabel, paste0(xlabel, "*", var_subgroup), deparse(formula))), design = data)
-
+        
         if (any(is.na(model.int))) {
         } else if (sum(grepl(":", names(coef(model.int)))) > 1) {
           model.int$call$formula <- as.formula(gsub(xlabel, paste0(xlabel, "*", var_subgroup), deparse(formula)))
           pv_anova <- survey::regTermTest(model.int, as.formula(paste0("~", xlabel, ":", var_subgroup)))
           pv_int <- round(pv_anova$p[1], decimal.pvalue)
         }
-
+        
         # KM 구하기(categorical인 경우만)
         if (!is.numeric(data$variables[[xlabel]])) {
           prop <- NULL
@@ -372,11 +398,11 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
         # Coxph 함수를 각 subgroup에 대해 적용시키기 위한 함수
         run_coxph <- function(subgroup_var, subgroup_value, data, formula, weights_option) {
           subset_data <- data[data[[subgroup_var]] == subgroup_value, ]
-
+          
           if (nrow(subset_data) == 0) {
             return(NULL)
           }
-
+          
           subset_weights <- if (weights_option) {
             as.numeric(as.character(subset_data[[weights]]))
           } else {
@@ -388,7 +414,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           )
           eval(cc)
         }
-
+        
         if (is.null(cluster)) {
           model <- sapply(var_subgroup, function(var) {
             if (is.factor(data[[var]])) {
@@ -402,7 +428,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           })
         } else {
           formula <- as.formula(paste0(deparse(formula), " + ", "cluster(", cluster, ")"))
-
+          
           model <- sapply(var_subgroup, function(var) {
             if (is.factor(data[[var]])) {
               unique_vals <- levels(data[[var]])
@@ -419,15 +445,15 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
         } else {
           NULL
         }
-
+        
         data %>%
           filter(!is.na(get(var_subgroup))) %>%
           select(dplyr::all_of(var_subgroup)) %>%
           table() %>%
           names() -> label_val
         xlev <- survival::coxph(formula, data = data)$xlevels
-
-
+        
+        
         # strata만 공식에 추가하는 경우 P for interaction에서 <NA>가 나타나는 문제가 있어 수정
         if (is.null(cluster) & is.null(weights) & !is.null(strata)) {
           model.int <- possible_coxph(as.formula(gsub(xlabel, paste0(xlabel, "*", var_subgroup), deparse(formula))), data = data)
@@ -439,8 +465,8 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           #   model.int <- tryCatch(eval(substitute(coxph(as.formula(gsub(xlabel, paste0(xlabel, "*", var_subgroup), deparse(formula))), data = data, weights = .weights), list(.weights = weights))), error = function(e) NA)
           # }
         }
-
-
+        
+        
         # KM 구하기(categorical인 경우만)
         if (!is.numeric(data[[xlabel]])) {
           prop <- NULL
@@ -450,18 +476,18 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
               split(.[[var_subgroup]]) %>%
               purrr::map(~ survival::survfit(formula.km, data = .)) %>%
               purrr::map(~ summary(., times = time_eventrate, extend = T))
-
+            
             prop <- matrix(nrow = length(res.kap.times), ncol = length(xlev[[1]]))
             colnames(prop) <- paste0(xlabel, "=", xlev[[1]])
             rownames(prop) <- names(res.kap.times)
-
+            
             sub_xlev <- data %>%
               filter(!is.na(get(var_subgroup))) %>%
               split(.[[var_subgroup]]) %>%
               lapply(function(x) {
                 sort(setdiff(unique(x[[xlabel]]), NA))
               })
-
+            
             for (i in rownames(prop)) {
               if (length(sub_xlev[[i]]) == 1) {
                 # prop[i, paste0(xlabel, "=", sub_xlev[[i]])] <- res.kap.times[["0"]][["surv"]]
@@ -470,20 +496,20 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
                 surv.df <- data.frame(res.kap.times[[i]][c("strata", "surv")])
                 for (j in colnames(prop)) {
                   tryCatch(prop[i, j] <- surv.df[surv.df$strata == j, "surv"],
-                    error = function(e) {
-                      prop[i, j] <- NA
-                    }
+                           error = function(e) {
+                             prop[i, j] <- NA
+                           }
                   )
                 }
               }
             }
-
+            
             prop <- round(100 * (1 - prop), decimal.percent)
           }, silent = )
         } else {
           prop <- NULL
         }
-
+        
         # pv_int 구하기
         if (any(is.na(model.int))) {
           pv_int <- NA
@@ -503,10 +529,10 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           pv_int <- tryCatch(round(pv_anova[nrow(pv_anova), 4], decimal.pvalue), error = function(e) NA)
         }
       }
-
+      
       # Count, PE, CI, PV 계산
       model %>% purrr::map_dbl("n", .default = NA) -> Count
-
+      
       if (ncoef < 2) {
         model %>%
           purrr::map("coefficients", .default = NA) %>%
@@ -514,7 +540,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
             round(exp(x[1:ncoef]), decimal.hr)
           }) %>%
           unlist() -> Point.Estimate
-
+        
         model %>%
           lapply(function(x) {
             tryCatch(
@@ -527,7 +553,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
             )
           }) %>%
           Reduce(rbind, .) -> CI
-
+        
         model %>%
           purrr::map(possible_pv) %>%
           purrr::map_dbl(~ round(., decimal.pvalue)) -> pv
@@ -537,7 +563,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           lapply(function(x) {
             round(exp(x[1:ncoef]), decimal.hr)
           }) -> Point.Estimate
-
+        
         model %>%
           purrr::map(possible_confint) %>%
           lapply(function(x) {
@@ -550,7 +576,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
               }
             )
           }) -> CI
-
+        
         model %>%
           lapply(function(x) {
             tryCatch(
@@ -563,39 +589,107 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
             )
           }) -> pv
       }
-
+      }
+      else{
+        prop<-NULL
+        label_val <- names(table(data[[var_subgroup]]))
+        rhs <- as.character(formula)[3]
+        fixed_effect <- gsub("\\+\\s*\\(.*\\)", "", rhs)
+        xlabel <- trimws(fixed_effect)
+        xlev <- levels(data[[xlabel]])
+        res_list <- lapply(label_val, function(lv) {
+          model <- coxme::coxme(formula, data = data[data[[var_subgroup]] == lv, ])
+          ms <- summary(model)
+          pe <- round(exp(ms$coef[, "coef"]), decimal.hr)
+          pe <- unname(pe)
+          lower <- round(exp(ms$coef[, "coef"] - 1.96 * ms$coef[, "se(coef)"]), decimal.hr)
+          upper <- round(exp(ms$coef[, "coef"] + 1.96 * ms$coef[, "se(coef)"]), decimal.hr)
+          lower <- unname(lower)
+          upper <- unname(upper)
+          if (length(pe) == 1) {
+            CI_mat <- matrix(c(lower, upper), nrow = 1, ncol = 2,
+                             dimnames = list(NULL, c("2.5 %", "97.5 %")))
+          } else {
+            CI_mat <- as.matrix(cbind(lower, upper))
+          }
+          pv_val <- round(ms$coef[, "p"], decimal.pvalue)
+          result_levels <- NULL  
+          list(
+            Point.Estimate = pe,
+            CI = CI_mat,
+            pv = pv_val,
+            result_levels = result_levels
+          )
+        })
+        CI <- lapply(res_list, function(x) x$CI)
+        Point.Estimate <- lapply(res_list, function(x) x$Point.Estimate)
+        pv <- lapply(res_list, function(x) x$pv)
+        result_levels <- lapply(res_list, function(x) x$result_levels)
+        if(is.factor(data[[xlabel]])) {
+          ncoef <- length(xlev) - 1
+        } else {
+          ncoef <- length(xlev)
+        }
+        Count <- as.vector(table(data[[var_subgroup]]))
+        total_count <- sum(Count)
+        interaction_formula <- as.formula(gsub(xlabel, paste0(xlabel, "*", var_subgroup), deparse(formula)))
+        model_int <- coxme::coxme(interaction_formula, data = data)
+        anova_res <- car::Anova(model_int)
+        inter_row <- grep(":", rownames(anova_res), value = TRUE)
+        if (length(inter_row) >= 1) {
+          pv_int <- round(anova_res[inter_row, "Pr(>Chisq)"], decimal.pvalue)
+        } else {
+          pv_int <- NA
+        }
+      }
       # output 만들기
       if (ncoef < 2) {
+        if (is_mixed_effect) {
+          CI<- do.call(rbind, lapply(CI, function(x) {
+          if (is.null(dim(x))) {
+            matrix(x, nrow = 1, dimnames = list(NULL, c("2.5 %", "97.5 %")))
+          } else {
+            x
+          }
+          }))
+          Point.Estimate<-unlist(Point.Estimate)
+          }
+
         out <- data.frame(Variable = paste("  ", label_val), Count = Count, Percent = round(Count / sum(Count) * 100, decimal.percent), `Point Estimate` = Point.Estimate, Lower = CI[, 1], Upper = CI[, 2], check.names = F, row.names = NULL) %>%
           mutate(`P value` = unlist(ifelse(pv >= 0.001, pv, "<0.001")), `P for interaction` = NA)
-
+        
         if (!is.null(prop)) {
           out <- data.frame(Variable = paste("  ", label_val), Count = Count, Percent = round(Count / sum(Count) * 100, decimal.percent), `Point Estimate` = Point.Estimate, Lower = CI[, 1], Upper = CI[, 2], check.names = F, row.names = NULL) %>%
             cbind(prop) %>%
             mutate(`P value` = unlist(ifelse(pv >= 0.001, pv, "<0.001")), `P for interaction` = NA)
         }
-
+        
         if (!is.null(labeldata)) {
           out$Variable <- paste0(" ", sapply(label_val, function(x) {
             labeldata[variable == var_subgroup & labeldata$level == x, val_label]
           }))
         }
-
+        
         rownames(out) <- NULL
-
+        
         var_subgroup_rev <- var_subgroup
         if (!is.null(labeldata)) {
           var_subgroup_rev <- labeldata[variable == var_subgroup, var_label[1]]
         }
-
         return(rbind(c(var_subgroup_rev, rep(NA, ncol(out) - 2), ifelse(pv_int >= 0.001, pv_int, "<0.001")), out))
       } else {
+        if (is_mixed_effect){
+          xlevel<-xlev
+        }
+        else{
+          xlevel<-xlev[[1]]
+        }
         out <- data.frame(
-          Variable = unlist(lapply(label_val, function(x) c(x, rep("", length(xlev[[1]]) - 1)))), Count = unlist(lapply(Count, function(x) c(x, rep("", length(xlev[[1]]) - 1)))), Percent = unlist(lapply(round(Count / sum(Count) * 100, decimal.percent), function(x) c(x, rep("", length(xlev[[1]]) - 1)))),
-          Levels = rep(paste0(xlabel, "=", xlev[[1]]), length(label_val)), `Point Estimate` = unlist(lapply(Point.Estimate, function(x) c("Reference", x))), Lower = unlist(lapply(CI, function(x) c("", x[, 1]))), Upper = unlist(lapply(CI, function(x) c("", x[, 2]))), check.names = F
+          Variable = unlist(lapply(label_val, function(x) c(x, rep("", length(xlevel) - 1)))), Count = unlist(lapply(Count, function(x) c(x, rep("", length(xlevel) - 1)))), Percent = unlist(lapply(round(Count / sum(Count) * 100, decimal.percent), function(x) c(x, rep("", length(xlevel) - 1)))),
+          Levels = rep(paste0(xlabel, "=", xlevel), length(label_val)), `Point Estimate` = unlist(lapply(Point.Estimate, function(x) c("Reference", x))), Lower = unlist(lapply(CI, function(x) c("", x[, 1]))), Upper = unlist(lapply(CI, function(x) c("", x[, 2]))), check.names = F
         ) %>%
           mutate(`P value` = unlist(lapply(pv, function(x) c("", ifelse(x >= 0.001, x, "<0.001")))), `P for interaction` = NA)
-
+        
         if (!is.null(prop)) {
           out <- data.frame(
             Variable = unlist(lapply(label_val, function(x) c(x, rep("", length(xlev[[1]]) - 1)))), Count = unlist(lapply(Count, function(x) c(x, rep("", length(xlev[[1]]) - 1)))), Percent = unlist(lapply(round(Count / sum(Count) * 100, decimal.percent), function(x) c(x, rep("", length(xlev[[1]]) - 1)))),
@@ -603,21 +697,21 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           ) %>%
             mutate(KM = as.vector(t(prop)), `P value` = unlist(lapply(pv, function(x) c("", ifelse(x >= 0.001, x, "<0.001")))), `P for interaction` = NA)
         }
-
+        
         if (!is.null(labeldata)) {
           out$Variable <- unlist(lapply(label_val, function(x) c(labeldata[variable == var_subgroup & labeldata$level == x, val_label], rep("", length(xlev[[1]]) - 1))))
           out$Levels <- rep(paste0(labeldata[variable == xlabel, var_label[1]], "=", sapply(xlev[[1]], function(x) {
             labeldata[variable == xlabel & labeldata$level == x, val_label]
           })), length(label_val))
         }
-
+        
         rownames(out) <- NULL
-
+        
         var_subgroup_rev <- var_subgroup
         if (!is.null(labeldata)) {
           var_subgroup_rev <- labeldata[variable == var_subgroup, var_label[1]]
         }
-
+        
         return(rbind(c(var_subgroup_rev, rep(NA, ncol(out) - 2), ifelse(pv_int >= 0.001, pv_int, "<0.001")), out))
       }
     }
@@ -660,7 +754,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           return(x)
         }
       })
-
+      
       count_output[[count_by]] <- sapply(count_output[[count_by]], function(x) {
         label <- labeldata[labeldata$variable == count_by & labeldata$level == x, "val_label"]
         if (length(label) > 0) {
@@ -713,7 +807,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           tibble::add_column(!!event_rate_col := NA, .after = "Count")
         value_to_insert <- count_output[count_output[[count_by]] == countlevel, "Event_Rate"]
         value_to_insert <- value_to_insert[!is.na(value_to_insert)]
-
+        
         original_output[[event_rate_col]][trimws(original_output[["Variable"]]) == "Overall"] <- value_to_insert[1]
       }
       count_output <- count_event_by(formula = formula, data = data, count_by_var = NULL, var_subgroup = var_subgroup, decimal.percent = 1)
@@ -724,7 +818,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
   if (!(event) && !is.null(count_by)) {
     original_output <- TableSubgroupCox(formula = formula, var_subgroup = var_subgroup, var_cov = var_cov, data = data, time_eventrate = time_eventrate, decimal.hr = decimal.hr, decimal.percent = decimal.percent, decimal.pvalue = decimal.pvalue, cluster = cluster, strata = strata, weights = weights, event = event, count_by = NULL, labeldata = labeldata)
     count_output <- count_event_by(formula = formula, data = data, count_by_var = count_by, var_subgroup = var_subgroup, decimal.percent = 1)
-
+    
     if (inherits(data, "survey.design")) {
       data <- data$variables
     } else {
@@ -741,7 +835,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           return(x)
         }
       })
-
+      
       count_output[[count_by]] <- sapply(count_output[[count_by]], function(x) {
         label <- labeldata[labeldata$variable == count_by & labeldata$level == x, "val_label"]
         if (length(label) > 0) {
@@ -751,7 +845,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
         }
       })
     }
-
+    
     if (!is.null(var_subgroup)) {
       subgroup_levels <- unique(data[[var_subgroup]])
       for (countlevel in count_by_levels) {
@@ -769,7 +863,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           original_output[[event_rate_col]][trimws(original_output[["Variable"]]) == level_label] <- value_to_insert[1]
         }
       }
-
+      
       return(original_output)
     } else {
       for (countlevel in count_by_levels) {
@@ -778,7 +872,7 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
           tibble::add_column(!!event_rate_col := NA, .after = "Count")
         value_to_insert <- count_output[count_output[[count_by]] == countlevel, "Count"]
         value_to_insert <- value_to_insert[!is.na(value_to_insert)]
-
+        
         original_output[[event_rate_col]][trimws(original_output[["Variable"]]) == "Overall"] <- value_to_insert[1]
       }
       return(original_output)
@@ -839,17 +933,17 @@ TableSubgroupCox <- function(formula, var_subgroup = NULL, var_cov = NULL, data,
 TableSubgroupMultiCox <- function(formula, var_subgroups = NULL, var_cov = NULL, data, time_eventrate = 3 * 365, decimal.hr = 2, decimal.percent = 1, decimal.pvalue = 3, line = F, cluster = NULL, strata = NULL, weights = NULL, event = FALSE, count_by = NULL, labeldata = NULL) {
   . <- NULL
   xlabel <- setdiff(as.character(formula)[[3]], "+")[1]
-
+  
   out.all <- TableSubgroupCox(formula, var_subgroup = NULL, var_cov = var_cov, data = data, time_eventrate = time_eventrate, decimal.hr = decimal.hr, decimal.percent = decimal.percent, decimal.pvalue = decimal.pvalue, cluster = cluster, strata = strata, weights = weights, event = event, count_by = count_by, labeldata = labeldata)
   out.all <- dplyr::mutate_all(out.all, as.character)
-
+  
   if (is.null(var_subgroups)) {
     return(out.all)
   } else {
     out.list <- lapply(var_subgroups, function(subgroup) {
       TableSubgroupCox(formula, var_subgroup = subgroup, var_cov = var_cov, data = data, time_eventrate = time_eventrate, decimal.hr = decimal.hr, decimal.percent = decimal.percent, decimal.pvalue = decimal.pvalue, cluster = cluster, strata = strata, weights = weights, event = event, count_by = count_by, labeldata = labeldata)
     })
-
+    
     # out.list <- purrr::map(var_subgroups, ~ TableSubgroupCox(formula, var_subgroup = ., var_cov = var_cov, data = data, time_eventrate = time_eventrate, decimal.hr = decimal.hr, decimal.percent = decimal.percent, decimal.pvalue = decimal.pvalue, cluster = cluster, weights = weights_vec))
     if (line) {
       out.newline <- out.list %>% purrr::map(~ rbind(NA, .))
@@ -862,4 +956,4 @@ TableSubgroupMultiCox <- function(formula, var_subgroups = NULL, var_cov = NULL,
       return(result)
     }
   }
-}
+}
\ No newline at end of file
