@@ -53,13 +53,13 @@ geeUni <- function(y, x, data, id.vec, family, cor.type = "exchangeable") {
 
 geeExp <- function(gee.coef, family = "binomial", dec) {
   if (family == "binomial") {
-    OR <- paste(round(exp(gee.coef[, 1]), dec), " (", round(exp(gee.coef[, 1] - 1.96 * gee.coef[, 2]), dec), ",", round(exp(gee.coef[, 1] + 1.96 * gee.coef[, 2]), dec), ")", sep = "")
+    OR <- ifelse(is.na(gee.coef[,1]), NA, paste(round(exp(gee.coef[, 1]), dec), " (", round(exp(gee.coef[, 1] - 1.96 * gee.coef[, 2]), dec), ",", round(exp(gee.coef[, 1] + 1.96 * gee.coef[, 2]), dec), ")", sep = ""))
     return(cbind(OR, gee.coef[, 3]))
   } else if (family == "gaussian") {
-    coeff <- paste(round(gee.coef[, 1], dec), " (", round(gee.coef[, 1] - 1.96 * gee.coef[, 2], dec), ",", round(gee.coef[, 1] + 1.96 * gee.coef[, 2], dec), ")", sep = "")
+    coeff <- ifelse(is.na(gee.coef[,1]),NA,paste(round(gee.coef[, 1], dec), " (", round(gee.coef[, 1] - 1.96 * gee.coef[, 2], dec), ",", round(gee.coef[, 1] + 1.96 * gee.coef[, 2], dec), ")", sep = ""))
     return(cbind(coeff, gee.coef[, 3]))
   } else if (family %in% c("poisson", "quasipoisson")) {
-    RR <- paste(round(exp(gee.coef[, 1]), dec), " (", round(exp(gee.coef[, 1] - 1.96 * gee.coef[, 2]), dec), ",", round(exp(gee.coef[, 1] + 1.96 * gee.coef[, 2]), dec), ")", sep = "")
+    RR <- ifelse(is.na(gee.coef[,1]),NA,paste(round(exp(gee.coef[, 1]), dec), " (", round(exp(gee.coef[, 1] - 1.96 * gee.coef[, 2]), dec), ",", round(exp(gee.coef[, 1] + 1.96 * gee.coef[, 2]), dec), ")", sep = ""))
     return(cbind(RR, gee.coef[, 3]))
   }
 }
@@ -70,6 +70,7 @@ geeExp <- function(gee.coef, family = "binomial", dec) {
 #' @description Make gee results from "geeglm" object
 #' @param geeglm.obj "geeglm" object
 #' @param decimal Decimal, Default: 2
+#' @param pcut.univariate pcut.univariate, Default: NULL
 #' @return List: caption, main table, metrics table
 #' @details DETAILS
 #' @examples
@@ -89,11 +90,17 @@ geeExp <- function(gee.coef, family = "binomial", dec) {
 #' @importFrom data.table data.table
 #' @importFrom stats complete.cases update formula
 
-geeglm.display <- function(geeglm.obj, decimal = 2) {
+geeglm.display <- function(geeglm.obj, decimal = 2, pcut.univariate=NULL) {
   family.gee <- geeglm.obj$family[[1]]
   corstr.gee <- geeglm.obj$corstr
   y <- as.character(geeglm.obj$terms[[2]])
   xs <- names(geeglm.obj$model)[-1]
+  
+  if (length(geeglm.obj$xlevels) != 0){
+    #xs.factor <- names(geeglm.obj$xlevels)[sapply(geeglm.obj$xlevels, function(x){length(x) > 2})]
+    xs.factor <- names(geeglm.obj$xlevels)
+  }
+  
   ## rownames
   geeglm.obj$data <- data.table::data.table(geeglm.obj$data)
   # nomiss <- stats::complete.cases(geeglm.obj$data[, c(y, xs), with = F])
@@ -122,8 +129,53 @@ geeglm.display <- function(geeglm.obj, decimal = 2) {
     family.label <- colnames(gee.res.modi)[1]
     colnames(gee.res.modi) <- c(paste(family.label, "(95%CI)", sep = ""), "P value")
   } else {
-    gee.multi <- summary(geeglm.obj)$coefficients[-1, -3]
-    gee.res <- cbind(geeExp(gee.uni, family = family.gee, dec = decimal), geeExp(gee.multi, family = family.gee, dec = decimal))
+    if (is.null(pcut.univariate)){
+      gee.multi <- summary(geeglm.obj)$coefficients[-1, -3]
+      gee.na <- gee.multi
+    }else{
+      significant_vars <- rownames(gee.uni)[as.numeric(gee.uni[, 3]) < pcut.univariate]
+
+      
+      if (length(geeglm.obj$xlevels) != 0){
+        factor_vars_list <- lapply(xs.factor, function(factor_var) {
+          factor_var_escaped <- gsub("\\(", "\\\\(", factor_var)  # "(" → "\\("
+          factor_var_escaped <- gsub("\\)", "\\\\)", factor_var_escaped)  # ")" → "\\)"
+          
+          #matches <- grep(paste0("^", factor_var_escaped), rownames(coefNA(model)), value = TRUE)
+          matches <- grep(paste0("^", factor_var_escaped), rownames(gee.uni), value = TRUE)
+  
+          return(matches)
+        })
+        names(factor_vars_list) <- xs.factor
+        
+        for (key in names(factor_vars_list)) {
+          variables <- factor_vars_list[[key]]
+          
+          p_values <- gee.uni[variables, 3]
+          
+          if (any(p_values < pcut.univariate, na.rm = TRUE)) {
+            significant_vars <- setdiff(significant_vars, variables)
+            
+            significant_vars <- unique(c(significant_vars, key))
+          }
+        }
+      }
+      
+      selected_formula <- as.formula(paste(y, "~", paste(significant_vars, collapse = " + ")))
+      selected_model <- geepack::geeglm(selected_formula, data = geeglm.obj$data, family = family.gee, id=geeglm.obj$id , corstr = corstr.gee) 
+      gee.multi <- summary(selected_model)$coefficients[-1, -3]
+      
+      
+      gee.na <- as.data.frame(matrix(NA, nrow = nrow(gee.uni), ncol = ncol(gee.uni)))
+      colnames(gee.na) <- colnames(gee.uni)
+      rownames(gee.na) <- rownames(gee.uni)
+      
+      row_indices <- match(rownames(gee.multi), rownames(gee.uni))
+      gee.na[row_indices, ] <- gee.multi
+      
+    }
+    
+    gee.res <- cbind(geeExp(gee.uni, family = family.gee, dec = decimal), geeExp(gee.na, family = family.gee, dec = decimal))
     gee.res.list <- lapply(1:length(xs), function(x) {
       gee.res[rownames(gee.uni) %in% rn.uni[[x]], ]
     })
