@@ -4,8 +4,9 @@ context("Show sub-group table")
 test_that("Run TableSubgroupMultiGLM", {
   library(survival)
   library(dplyr)
+  library(magrittr)
   lung %>%
-    mutate(
+    dplyr::mutate(
       status = as.integer(status == 1),
       sex = factor(sex),
       kk = factor(as.integer(pat.karno >= 70)),
@@ -15,6 +16,7 @@ test_that("Run TableSubgroupMultiGLM", {
   expect_is(TableSubgroupMultiGLM(status ~ sex, data = lung, family = "binomial"), "data.frame")
   expect_is(TableSubgroupMultiGLM(status ~ sex, var_subgroups = c("kk", "kk1"), data = lung, family = "binomial"), "data.frame")
   expect_is(TableSubgroupMultiGLM(pat.karno ~ sex, var_subgroups = c("kk", "kk1"), data = lung, family = "gaussian", line = TRUE), "data.frame")
+  expect_is(TableSubgroupMultiGLM(status ~ sex + (1 | inst), var_subgroups = c("kk", "kk1"), data = lung, family = "gaussian", line = TRUE), "data.frame")
 
   ## Survey data
   library(survey)
